package com.ruoyi.base.mapper;

import java.util.List;
import com.ruoyi.base.domain.RobotOpsBroadcastContent;

/**
 * 播报内容Mapper接口
 * 
 * @author ruoyi
 * @date 2026-04-27
 */
public interface RobotOpsBroadcastContentMapper 
{
    /**
     * 查询播报内容
     * 
     * @param id 播报内容主键
     * @return 播报内容
     */
    public RobotOpsBroadcastContent selectRobotOpsBroadcastContentById(Long id);

    /**
     * 查询播报内容列表
     * 
     * @param robotOpsBroadcastContent 播报内容
     * @return 播报内容集合
     */
    public List<RobotOpsBroadcastContent> selectRobotOpsBroadcastContentList(RobotOpsBroadcastContent robotOpsBroadcastContent);

    /**
     * 新增播报内容
     * 
     * @param robotOpsBroadcastContent 播报内容
     * @return 结果
     */
    public int insertRobotOpsBroadcastContent(RobotOpsBroadcastContent robotOpsBroadcastContent);

    /**
     * 修改播报内容
     * 
     * @param robotOpsBroadcastContent 播报内容
     * @return 结果
     */
    public int updateRobotOpsBroadcastContent(RobotOpsBroadcastContent robotOpsBroadcastContent);

    /**
     * 删除播报内容
     * 
     * @param id 播报内容主键
     * @return 结果
     */
    public int deleteRobotOpsBroadcastContentById(Long id);

    /**
     * 批量删除播报内容
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRobotOpsBroadcastContentByIds(Long[] ids);
}
